-
2057143·text·541 B·2011-05-12 02:17 UTC
tried to execute this:
(add-to-list 'package-archives '("marmalade" .
"http://marmalade-repo.org/packages/"))
got this:
Debugger entered--Lisp error: (void-variable package-archives)
-
2057142·text·406 B·2011-05-12 02:17 UTC
Debugger entered--Lisp error: (void-variable package-archives)
add-to-list(package-archives ("marmalade" . "http://marmalade-repo.org/packages/"))
eval((add-to-list (quote package-archives) (quo
-
2057137·sql·1.4 KB·2011-05-12 01:49 UTC
+-------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-
2057135·text·2.8 KB·2011-05-12 01:25 UTC
8:07,363 - ubuntuone.SyncDaemon.local_rescan - ERROR - in the scan: <type 'exceptions.AttributeError'> ('_MDObject' object has no attribute 'crc32')
Traceback (most recent call last):
File "/usr/l
-
2057134·text·6 B·2011-05-12 01:24 UTC
Draft
-
2057133·c·2.1 KB·2011-05-12 01:23 UTC
#include <conio.h>
#include <stdio.h>
#include <string.h>
#define TOTAL_VECTOR 30
//Prototipo
int validarnum (int,int,int);
char validarcad (char [],int);
void main() {
int legajo[TOTAL_
-
2057132·text·2 B·2011-05-12 01:22 UTC
-
2057130·text·5.1 KB·2011-05-12 01:14 UTC
seta com_allowConsole "1"
seta com_machineSpec "0"
seta com_useFastVidRestart "0"
//seta com_useFastVidRestart "1"
seta com_showfps "1"
seta com_videoRam "512"
//seta com_videoRam "2048"
// [
-
2057129·text·4.3 KB·2011-05-12 01:12 UTC
// *********************************************************
// This file is managed by Brink and will be overwritten
// Any custom commands or bindings should be put into 'autoexec.cfg'
// in the
-
2057127·text·128 B·2011-05-12 01:11 UTC
(gdb) pstruct teste
teste
{
list_length length 0
char * id 0x602010 "testando"
Element * first 0x0
Element * last 0x0
}
-
2057116·text·13.2 KB·2011-05-12 00:45 UTC
Question 1 (1.00 points)
Americans' national identity rests largely upon
a. ethnic kinship.
b. common language.
c. shared political ideals.
d. religion.
e. federal law.
-
2057115·text·800 B·2011-05-12 00:41 UTC
if (horaTermino >= horaInicio)
{
durHora = (((horaTermino * 60)+ minTermino) - ((horaInicio * 60) + minInicio))/60;
}
else
{
durHora = ((((horaTermino + 24)* 60) + m
-
2057106·text·22.2 KB·2011-05-11 23:49 UTC
!!################################
!!ALSA Information Script v 0.4.41
!!################################
!!Script ran on: Wed May 11 19:49:22 EDT 2011
!!Linux Distribution
!!------------------
Fe
-
2057104·text·3.5 KB·2011-05-11 23:34 UTC
# Don't display the copyright notice during startup
startup_message off
# Remember 5000 lines of history
defscrollback 5000
# Bind F1 through F7 to switch to window 0 through 6, respectively
-
2057097·text·128 B·2011-05-11 23:26 UTC
[Wed May 11 16:25:30 2011].666748 msPostGISLayerIsOpen called.
[Wed May 11 16:25:30 2011].666795 msPostGISLayerIsOpen called.
-
2057096·text·2.2 KB·2011-05-11 23:26 UTC
list list verbs in category 'benchmarks'
dlls list list verbs in category 'dlls'
games list list verbs in category 'games'
settings list list verbs in category
-
2057092·text·19.6 KB·2011-05-11 23:02 UTC
I. Introduction
An often-discussed topic in the contemporary socio-political discourse is the threat of what is described as Radical Islam to the stability of not only the Middle East region, but th
-
2057091·text·380 B·2011-05-11 23:00 UTC
mail [04:06:56]~
whodevil>sup-mail
[Wed May 11 16:07:00 -0700 2011] No 'ncursesw' gem detected. Install it for wide character support.
Error: the index is locked by another process! User '' on
hos
-
2057089·text·112 B·2011-05-11 22:56 UTC
陽圧式防護服を着用した消防隊員。2003年横浜市緑消防署出初め式にて投稿者撮影。
-
2057086·c·5.9 KB·2011-05-11 22:47 UTC
__global__ static void SzimulacioKernel(int* ELETTER, int* ELETKOR, int* EHSEG, int* SZAPOR, int* LEPETT)
{
int x = blockIdx.x * blockDim.x + threadIdx.x;
int y = blockIdx.y * blockDim.y + thread